@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoGameOver.cpp,v 1.9 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: DemoGameOver.cpp,v 1.10 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -249,7 +249,7 @@ bool DemoGameOver::draw()
 		// ڤؤ
 		wait_time = time( NULL ) + GAME_OVER_WAIT_TIME;
 		frame = 0;
-		change_scene( SCENE_N_GAME_OVER_WAIT );
+		change_scene_gui( SCENE_N_GAME_OVER_WAIT );
 	}
 
 	if( get_scene() == SCENE_N_GAME_OVER_WAIT ){
@@ -264,7 +264,7 @@ bool DemoGameOver::draw()
 			// ڤؤ
 			gPcgDun.scrollTile( 0, 0 );
 			frame = 0;
-			change_scene( SCENE_N_GAME_OVER_END );
+			change_scene_gui( SCENE_N_GAME_OVER_END );
 		}
 	}
 
