@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiLastBoss.cpp,v 1.16 2009/01/24 16:15:28 bowkenken Exp $
+* $Id: GuiLastBoss.cpp,v 1.18 2009/06/06 06:27:31 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -87,6 +87,100 @@ GuiLastBoss::~GuiLastBoss()
 
 void GuiLastBoss::init()
 {
+	long r = gPcgDun.nTileSizeRate;
+	jointSkullToJaw.x = jointSkullToJaw.x
+			* r / _100_PERCENT;
+	jointSkullToJaw.y = jointSkullToJaw.y
+			* r / _100_PERCENT;
+	jointJawToSkull.x = jointJawToSkull.x
+			* r / _100_PERCENT;
+	jointJawToSkull.y = jointJawToSkull.y
+			* r / _100_PERCENT;
+	jointJawToSkullOpen.x = jointJawToSkullOpen.x
+			* r / _100_PERCENT;
+	jointJawToSkullOpen.y = jointJawToSkullOpen.y
+			* r / _100_PERCENT;
+	jointSkullToBody.x = jointSkullToBody.x
+			* r / _100_PERCENT;
+	jointSkullToBody.y = jointSkullToBody.y
+			* r / _100_PERCENT;
+	jointBodyToSkull.x = jointBodyToSkull.x
+			* r / _100_PERCENT;
+	jointBodyToSkull.y = jointBodyToSkull.y
+			* r / _100_PERCENT;
+	jointBodyToUpperArmLeft.x = jointBodyToUpperArmLeft.x
+			* r / _100_PERCENT;
+	jointBodyToUpperArmLeft.y = jointBodyToUpperArmLeft.y
+			* r / _100_PERCENT;
+	jointBodyToUpperArmRight.x = jointBodyToUpperArmRight.x
+			* r / _100_PERCENT;
+	jointBodyToUpperArmRight.y = jointBodyToUpperArmRight.y
+			* r / _100_PERCENT;
+	jointUpperArmToBodyLeft.x = jointUpperArmToBodyLeft.x
+			* r / _100_PERCENT;
+	jointUpperArmToBodyLeft.y = jointUpperArmToBodyLeft.y
+			* r / _100_PERCENT;
+	jointUpperArmToBodyRight.x = jointUpperArmToBodyRight.x
+			* r / _100_PERCENT;
+	jointUpperArmToBodyRight.y = jointUpperArmToBodyRight.y
+			* r / _100_PERCENT;
+	jointUpperArmToForeArmLeft.x = jointUpperArmToForeArmLeft.x
+			* r / _100_PERCENT;
+	jointUpperArmToForeArmLeft.y = jointUpperArmToForeArmLeft.y
+			* r / _100_PERCENT;
+	jointUpperArmToForeArmRight.x = jointUpperArmToForeArmRight.x
+			* r / _100_PERCENT;
+	jointUpperArmToForeArmRight.y = jointUpperArmToForeArmRight.y
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmLeft.x = jointForeArmToUpperArmLeft.x
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmLeft.y = jointForeArmToUpperArmLeft.y
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmRight.x = jointForeArmToUpperArmRight.x
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmRight.y = jointForeArmToUpperArmRight.y
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmSlapLeft.x = jointForeArmToUpperArmSlapLeft.x
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmSlapLeft.y = jointForeArmToUpperArmSlapLeft.y
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmSlapRight.x = jointForeArmToUpperArmSlapRight.x
+			* r / _100_PERCENT;
+	jointForeArmToUpperArmSlapRight.y = jointForeArmToUpperArmSlapRight.y
+			* r / _100_PERCENT;
+	jointForeArmToHandLeft.x = jointForeArmToHandLeft.x
+			* r / _100_PERCENT;
+	jointForeArmToHandLeft.y = jointForeArmToHandLeft.y
+			* r / _100_PERCENT;
+	jointForeArmToHandRight.x = jointForeArmToHandRight.x
+			* r / _100_PERCENT;
+	jointForeArmToHandRight.y = jointForeArmToHandRight.y
+			* r / _100_PERCENT;
+	jointForeArmToHandSlapLeft.x = jointForeArmToHandSlapLeft.x
+			* r / _100_PERCENT;
+	jointForeArmToHandSlapLeft.y = jointForeArmToHandSlapLeft.y
+			* r / _100_PERCENT;
+	jointForeArmToHandSlapRight.x = jointForeArmToHandSlapRight.x
+			* r / _100_PERCENT;
+	jointForeArmToHandSlapRight.y = jointForeArmToHandSlapRight.y
+			* r / _100_PERCENT;
+	jointHandToForeArmLeft.x = jointHandToForeArmLeft.x
+			* r / _100_PERCENT;
+	jointHandToForeArmLeft.y = jointHandToForeArmLeft.y
+			* r / _100_PERCENT;
+	jointHandToForeArmRight.x = jointHandToForeArmRight.x
+			* r / _100_PERCENT;
+	jointHandToForeArmRight.y = jointHandToForeArmRight.y
+			* r / _100_PERCENT;
+	jointHandToForeArmSlapLeft.x = jointHandToForeArmSlapLeft.x
+			* r / _100_PERCENT;
+	jointHandToForeArmSlapLeft.y = jointHandToForeArmSlapLeft.y
+			* r / _100_PERCENT;
+	jointHandToForeArmSlapRight.x = jointHandToForeArmSlapRight.x
+			* r / _100_PERCENT;
+	jointHandToForeArmSlapRight.y = jointHandToForeArmSlapRight.y
+			* r / _100_PERCENT;
+
 	initPcg( &pcgSkull, "last_boss/skull/" );
 	initPcg( &pcgJaw, "last_boss/jaw/" );
 	initPcg( &pcgBody, "last_boss/body/" );
@@ -181,7 +275,7 @@ void GuiLastBoss::setDraw()
 
 	last_scene_n_t sc = get_last_scene();
 	if( (sc < LAST_SCENE_N_XX_ENTER)
-			&& (LAST_SCENE_N_XX_DIE <= sc) ){
+			|| (LAST_SCENE_N_XX_DIE <= sc) ){
 		return;
 	}
 
@@ -358,7 +452,7 @@ void GuiLastBoss::drawBg()
 
 	last_scene_n_t sc = get_last_scene();
 	if( (sc < LAST_SCENE_N_XX_ENTER)
-			&& (LAST_SCENE_N_XX_DIE <= sc) ){
+			|| (LAST_SCENE_N_XX_DIE <= sc) ){
 		return;
 	}
 
@@ -366,27 +460,19 @@ void GuiLastBoss::drawBg()
 
 	// 
 
-	pcgBody.draw( gPcgDun.getWBuf(),
-			bodyX, bodyY,
-			bodyW, bodyH );
+	drawPcg( &pcgBody, bodyX, bodyY, bodyW, bodyH );
 
 	if( get_open_xx_jaw() ){
-		pcgJaw.draw( gPcgDun.getWBuf(),
-				jawOpenX, jawOpenY,
-				jawOpenW, jawOpenH );
+		drawPcg( &pcgJaw, jawOpenX, jawOpenY, jawOpenW, jawOpenH );
 	} else {
-		pcgJaw.draw( gPcgDun.getWBuf(),
-				jawX, jawY,
-				jawW, jawH );
+		drawPcg( &pcgJaw, jawX, jawY, jawW, jawH );
 	}
 
-	pcgSkull.draw( gPcgDun.getWBuf(),
-			skullX, skullY,
-			skullW, skullH );
-	pcgUpperArmLeft.draw( gPcgDun.getWBuf(),
+	drawPcg( &pcgSkull, skullX, skullY, skullW, skullH );
+	drawPcg( &pcgUpperArmLeft,
 			upperArmLeftX, upperArmLeftY,
 			upperArmLeftW, upperArmLeftH );
-	pcgUpperArmRight.draw( gPcgDun.getWBuf(),
+	drawPcg( &pcgUpperArmRight,
 			upperArmRightX, upperArmRightY,
 			upperArmRightW, upperArmRightH );
 }
@@ -402,7 +488,7 @@ void GuiLastBoss::drawFg()
 
 	last_scene_n_t sc = get_last_scene();
 	if( (sc < LAST_SCENE_N_XX_ENTER)
-			&& (LAST_SCENE_N_XX_DIE <= sc) ){
+			|| (LAST_SCENE_N_XX_DIE <= sc) ){
 		return;
 	}
 
@@ -411,42 +497,59 @@ void GuiLastBoss::drawFg()
 	// 
 
 	if( get_slap_xx_arm_left() ){
-		pcgForeArmSlapLeft.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgForeArmSlapLeft,
 				foreArmSlapLeftX, foreArmSlapLeftY,
 				foreArmSlapLeftW, foreArmSlapLeftH );
 
-		pcgHandSlapLeft.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgHandSlapLeft,
 				handSlapLeftX, handSlapLeftY,
 				handSlapLeftW, handSlapLeftH );
 	} else {
-		pcgForeArmLeft.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgForeArmLeft,
 				foreArmLeftX, foreArmLeftY,
 				foreArmLeftW, foreArmLeftH );
 
-		pcgHandLeft.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgHandLeft,
 				handLeftX, handLeftY,
 				handLeftW, handLeftH );
 	}
 
 	if( get_slap_xx_arm_right() ){
-		pcgForeArmSlapRight.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgForeArmSlapRight,
 				foreArmSlapRightX, foreArmSlapRightY,
 				foreArmSlapRightW, foreArmSlapRightH );
 
-		pcgHandSlapRight.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgHandSlapRight,
 				handSlapRightX, handSlapRightY,
 				handSlapRightW, handSlapRightH );
 	} else {
-		pcgForeArmRight.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgForeArmRight,
 				foreArmRightX, foreArmRightY,
 				foreArmRightW, foreArmRightH );
 
-		pcgHandRight.draw( gPcgDun.getWBuf(),
+		drawPcg( &pcgHandRight,
 				handRightX, handRightY,
 				handRightW, handRightH );
 	}
 }
 
+////////////////////////////////////////////////////////////////
+//  (ط)
+// Pcg *p : ѥ
+// long x : X ɸ
+// long y : Y ɸ
+// long w : 
+// long h : ⤵
+////////////////////////////////////////////////////////////////
+
+void GuiLastBoss::drawPcg( Pcg *p, long x, long y, long w, long h )
+{
+	if( p == NULL )
+		return;
+
+	p->draw( gPcgDun.getWBuf(), x, y, w, h );
+}
+
 ////////////////////////////////////////////////////////////////
 // XX ιǡ
 // xx_act_kind_t kind : μ
@@ -460,7 +563,7 @@ void GuiLastBoss::setXxAttack( xx_act_kind_t kind, void *p )
 
 	last_scene_n_t sc = get_last_scene();
 	if( (sc < LAST_SCENE_N_XX_ENTER)
-			&& (LAST_SCENE_N_XX_DIE <= sc) ){
+			|| (LAST_SCENE_N_XX_DIE <= sc) ){
 		return;
 	}
 
