@@ -25,81 +25,18 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.39 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.40 2009/06/21 13:47:44 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-//#include	"turn.h"
-//#include	"dun.h"
-//#include	"town.h"
-//#include	"item.h"
-//#include	"spell.h"
-//#include	"chr.h"
-//#include	"party.h"
-//#include	"mnstr.h"
-//#include	"pet.h"
-//#include	"fight.h"
-//#include	"fx.h"
-//#include	"trap.h"
-#include	"draw.h"
-//#include	"curs.h"
-#include	"menu.h"
-//#include	"amenu.h"
-//#include	"request.h"
-//#include	"gfile.h"
-#include	"msg.h"
-//#include	"ver.h"
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-//#include	"turn-prot.h"
-//#include	"dun-prot.h"
-//#include	"town-prot.h"
-//#include	"item-prot.h"
-//#include	"spell-prot.h"
-//#include	"chr-prot.h"
-//#include	"party-prot.h"
-//#include	"mnstr-prot.h"
-//#include	"pet-prot.h"
-//#include	"fight-prot.h"
-//#include	"fx-prot.h"
-//#include	"trap-prot.h"
-#include	"draw-prot.h"
-//#include	"curs-prot.h"
-//#include	"menu-prot.h"
-//#include	"tmenu-prot.h"
-//#include	"amenu-prot.h"
-//#include	"request-prot.h"
-//#include	"gfile-prot.h"
-//#include	"msg-prot.h"
-
+////////////////////////////////////////////////////////////////
+// ˥塼ɥ
 ////////////////////////////////////////////////////////////////
 
-#ifdef D_WS
-# include <WSCwindow.h>
-# include <WSCbase.h>
-# include <WSCvbtn.h>
-# include <WSDmouse.h>
-#endif // D_WS
-
-#ifdef D_GTK
-# include <gtk/gtk.h>
-# include <gdk/gdk.h>
-#endif // D_GTK
-
-#include "GuiMenu.h"
-#include "GlobalVar.h"
-
-#ifdef D_GTK
-# include "main-gtk-prot.h"
-#endif // D_GTK
-
-#ifdef D_MFC
-# include "xlnl-dows/stdafx.h"
-# include "xlnl-dows/xlnl-dows.h"
-# include "xlnl-dows/MenuWnd.h"
-#endif // D_MFC
+#define GUI_MENU_CPP
+#include "inc.h"
 
+////////////////////////////////////////////////////////////////
+// ѿ
 ////////////////////////////////////////////////////////////////
 
 #define	GUI_MENU_BTN_MARGIN_X	4
@@ -112,6 +49,8 @@ extern WSCvbtn *MenuBtnPrevPage, *MenuBtnNextPage;
 extern WSCvlabel *MenuLabelPage;
 #endif // D_WS
 
+////////////////////////////////////////////////////////////////
+// ٥ȡϥɥ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_WS
@@ -596,6 +535,18 @@ void GuiMenu::draw( draw_menu_t *data )
 
 		WSCstring msgContents = data->ls[i]->msg;
 
+		// 
+
+		WSCstring msgSelectLeft = " ";
+		WSCstring msgSelectRight = " ";
+		if( i == data->sel_n ){
+			msgSelectLeft = MSG_MENU_SELECT_GUI_LEFT;
+			msgSelectRight = MSG_MENU_SELECT_GUI_RIGHT;
+		} else {
+			msgSelectLeft = MSG_MENU_NOT_SELECT_GUI_LEFT;
+			msgSelectRight = MSG_MENU_NOT_SELECT_GUI_RIGHT;
+		}
+
 		// 졼
 
 		WSCstring msgAccel = "";
@@ -645,11 +596,13 @@ void GuiMenu::draw( draw_menu_t *data )
 		// ˥塼ܥΥ٥
 
 		WSCstring msg = "";
+		msg += msgSelectLeft;
 		msg += msgChk + msgAccel;
 		msg += msgContents;
 		msg += WSCstring( " " ) + msgOpenWin;
 		msg += WSCstring( " " ) + msgShort;
 		msg += WSCstring( " " ) + msgBranch;
+		msg += msgSelectRight;
 
 		// ȥ롦ܥΥץѥƥ
 
