@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.cpp,v 1.47 2008/09/20 22:36:14 bowkenken Exp $
+* $Id: GuiMessage.cpp,v 1.49 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -61,7 +61,7 @@
 gint handle_message_delete(
 	GtkWidget *widget, gpointer user_data
 );
-void handle_message_destroy(
+gint handle_message_destroy(
 	GtkWidget *widget, gpointer user_data
 );
 gint handle_message_expose(
@@ -70,10 +70,16 @@ gint handle_message_expose(
 gint handle_message_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 );
+gint handle_message_da_expose(
+	GtkWidget *widget, GdkEventExpose *event
+);
+gint handle_message_da_configure(
+	GtkWidget *widget, GdkEventConfigure *event
+);
 gint handle_message_scroll_wheel(
 	GtkWidget *widget, GdkEventScroll *event
 );
-void handle_message_scroll_changed(
+gint handle_message_scroll_changed(
 	GtkAdjustment *adjustment,
 	gpointer user_data
 );
@@ -179,6 +185,10 @@ void GuiMessage::newWin()
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_message_destroy ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mMessageWin ),
+			"expose_event",
+			GTK_SIGNAL_FUNC( handle_message_expose ),
+			this );
 
 	// 襨ꥢ
 
@@ -207,11 +217,11 @@ void GuiMessage::newWin()
 
 	gtk_signal_connect( GTK_OBJECT( mMessageDrawingArea ),
 			"expose_event",
-			GTK_SIGNAL_FUNC( handle_message_expose ),
+			GTK_SIGNAL_FUNC( handle_message_da_expose ),
 			NULL );
 	gtk_signal_connect( GTK_OBJECT( mMessageDrawingArea ),
 			"configure_event",
-			GTK_SIGNAL_FUNC( handle_message_configure ),
+			GTK_SIGNAL_FUNC( handle_message_da_configure ),
 			NULL );
 	gtk_signal_connect( GTK_OBJECT( mMessageDrawingArea ),
 			"scroll_event",
@@ -629,10 +639,6 @@ void GuiMessage::draw( bool flagRedraw )
 	delete pen;
 	delete brush;
 #endif // D_MFC
-
-	gWinPos[WIN_KIND_MESSAGE].get( WIN_KIND_MESSAGE,
-			NULL, NULL, NULL, NULL );
-	gWinPos[WIN_KIND_MESSAGE].draw( WIN_KIND_MESSAGE );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -767,7 +773,7 @@ gint handle_message_delete(
 {
 	gGuiMessage.wipe();
 
-	return true;
+	return 0;
 }
 #endif // D_GTK
 
@@ -778,11 +784,13 @@ gint handle_message_delete(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_message_destroy(
+gint handle_message_destroy(
 	GtkWidget *widget, gpointer data
 )
 {
 	gGuiMessage.destroy();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -798,10 +806,11 @@ gint handle_message_expose(
 	GtkWidget *widget, GdkEventExpose *event
 )
 {
-	gGuiMessage.redraw();
-	gGuiMessage.drawScrollBar();
+	gWinPos[WIN_KIND_MESSAGE].get( WIN_KIND_MESSAGE,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_MESSAGE].draw( WIN_KIND_MESSAGE );
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -820,7 +829,45 @@ gint handle_message_configure(
 	gGuiMessage.redraw();
 	gGuiMessage.drawScrollBar();
 
-	return TRUE;
+	return 0;
+}
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// åɥ襤٥Ȥν
+// GtkWidget *widget : åΥɥ󥰡ꥢ
+// GdkEventExpose *event : ٥
+// return : ?
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_message_da_expose(
+	GtkWidget *widget, GdkEventExpose *event
+)
+{
+	gGuiMessage.redraw();
+	gGuiMessage.drawScrollBar();
+
+	return 0;
+}
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// åɥΥѹ٥Ȥν
+// GtkWidget *widget : åΥɥ󥰡ꥢ
+// GdkEventConfigure *event : ٥
+// return : ?
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_message_da_configure(
+	GtkWidget *widget, GdkEventConfigure *event
+)
+{
+	gGuiMessage.redraw();
+	gGuiMessage.drawScrollBar();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -852,7 +899,7 @@ gint handle_message_scroll_wheel(
 		break;
 	}
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -863,11 +910,13 @@ gint handle_message_scroll_wheel(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_message_scroll_changed(
+gint handle_message_scroll_changed(
 	GtkAdjustment *adjustment,
 	gpointer user_data
 )
 {
 	gGuiMessage.redraw();
+
+	return 0;
 }
 #endif // D_GTK
