@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.cpp,v 1.8 2009/05/23 15:59:50 bowkenken Exp $
+* $Id: GuiWords.cpp,v 1.10 2009/06/24 10:44:49 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -199,11 +199,12 @@ void GuiWords::destroy()
 
 ////////////////////////////////////////////////////////////////
 // 쥦ɥɽ
+// const char *name : ̾
 // const char *str : 
 // long w : ɽ
 ////////////////////////////////////////////////////////////////
 
-void GuiWords::draw( const char *str, long w )
+void GuiWords::draw( const char *name, const char *str, long w )
 {
 	newWin();
 
@@ -221,14 +222,24 @@ void GuiWords::draw( const char *str, long w )
 	gtk_text_buffer_get_end_iter( buf, &end );
 	gtk_text_buffer_delete( buf, &bgn, &end );
 
-	// ƥȤɲ
+	// ̾ɲ
 
 	gtk_text_buffer_get_end_iter( buf, &cur );
+	static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long nLineMaxLen = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
+
+	if( name != NULL ){
+		sn_printf( line, nLineMaxLen,
+				MSG_FMT_DRAW_WORDS_NAME, name );
+		gtk_text_buffer_insert( buf, &cur,
+				line, str_len_std( line ) );
+		gtk_text_buffer_insert( buf, &cur, "\n", 1 );
+	}
+
+	// ƥȤɲ
 
 	const char *head, *tail;
 	for( head = str; ; head = tail ){
-		static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
-
 		tail = get_words_line( head, w );
 		if( tail == NULL )
 			break;
@@ -249,12 +260,19 @@ void GuiWords::draw( const char *str, long w )
 		return;
 
 	CString buf;
-	const char *head, *tail;
+	static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long nLineMaxLen = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
 
+	if( name != NULL ){
+		sn_printf( line, nLineMaxLen,
+				MSG_FMT_DRAW_WORDS_NAME, name );
+		buf += line;
+		buf += "\r\n";
+	}
+
+	const char *head, *tail;
 	head = str;
 	for( long i = 0; i < LOOP_MAX_1000; i++ ){
-		static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
-
 		tail = get_words_line( head, w );
 		if( tail == NULL )
 			break;
