@@ -25,53 +25,15 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.35 2009/03/11 19:00:53 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.36 2009/05/28 08:44:49 bowkenken Exp $
 ***************************************************************/
 
-#ifdef D_WS
-# include <WScom.h>
-# include <WSCfunctionList.h>
-# include <WSCbase.h>
+////////////////////////////////////////////////////////////////
+// ޥΥ롦Хå
+////////////////////////////////////////////////////////////////
 
-# include <WSCvscrBar.h>
-# include <WSCwindow.h>
-#endif // D_WS
-
-#ifdef D_GTK
-# include <gtk/gtk.h>
-#endif // D_GTK
-
-#ifdef D_MFC
-# include "xlnl-dows/stdafx.h"
-# include "xlnl-dows/xlnl-dows.h"
-# include "xlnl-dows/MainFrm.h"
-#endif // D_MFC
-
-#include "gmain.h"
-#include "replay.h"
-#include "party.h"
-#include "draw.h"
-#include "menu.h"
-#include "gmain-prot.h"
-#include "replay-prot.h"
-#include "party-prot.h"
-#include "draw-prot.h"
-#include "menu-prot.h"
-#include "mmenu-prot.h"
-#include "imenu-prot.h"
-
-#include "GraphConf.h"
-#include "MouseMap.h"
-#include "Key.h"
-#include "GlobalVar.h"
-
-#ifdef D_GTK
-# include "main-gtk-prot.h"
-#endif // D_GTK
-
-#ifdef D_MFC
-# include "main-dows-prot.h"
-#endif // D_MFC
+#define	MOUSE_MAP_CPP	1
+#include "inc.h"
 
 ////////////////////////////////////////////////////////////////
 
@@ -485,7 +447,7 @@ print_msg( 0, "55555" );//@@@
 		if( n == MouseMotion::nMouseButtonR )
 			gSelMbrGraph->cancel();
 	} else {
-		callFuncKey( FUNC_N_CLICK_0 + n );
+		callFuncKey( FUNC_N_CLICK_0 + n, true );
 	}
 #endif
 }
@@ -782,16 +744,30 @@ void funcMotionScroll(
 ////////////////////////////////////////////////////////////////
 // ޥ⡼ե󥯥󡦥Ѵ
 // long fn : ե󥯥󡦥ֹ
+// bool flagCheckClear : ԡȤХåեˤʤ
 // return : 顼̵ä?
 ////////////////////////////////////////////////////////////////
 
-bool callFuncKey( long fn )
+bool callFuncKey( long fn, bool flagCheckClear )
 {
 	if( fn < 0 )
 		return false;
 	if( fn > FUNC_KEY_MAX )
 		return false;
 
+	do {
+		if( !flagCheckClear )
+			break;
+		if( !g_flg_clr_key_buf )
+			break;
+		if( !chk_key_buf() )
+			break;
+		if( !chk_flg_run_exec_all_phase() )
+			break;
+
+		return true;
+	} while( 0 );
+
 	char str[15 + 1];
 	sprintf( str, "&%2ld", (long)fn );
 	gKey.setString( str );
