@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelMbrGraph.cpp,v 1.7 2009/05/14 08:33:26 bowkenken Exp $
+* $Id: SelMbrGraph.cpp,v 1.8 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -145,7 +145,7 @@ SelMbrGraph::SelMbrGraph()
 SelMbrGraph::~SelMbrGraph()
 {
 	if( nPreScene != SCENE_N_NULL )
-		change_scene( nPreScene );
+		change_scene_gui( nPreScene );
 
 	if( nPreMapX > -1 )
 		gPcgDun.setScrollBarX( nPreMapX );
@@ -195,7 +195,7 @@ bool SelMbrGraph::exec( mbr_t *mbr )
 	// 
 
 	nPreScene = get_scene();
-	change_scene( SCENE_N_SEL_MBR_GRAPH );
+	change_scene_gui( SCENE_N_SEL_MBR_GRAPH );
 
 	// ѥ󸡺
 
@@ -337,7 +337,7 @@ void SelMbrGraph::cancel()
 void SelMbrGraph::close()
 {
 	if( nPreScene != SCENE_N_NULL )
-		change_scene( nPreScene );
+		change_scene_gui( nPreScene );
 	nPreScene = SCENE_N_NULL;
 
 	gPcgDun.redraw();
