@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.105 2009/06/06 10:18:49 bowkenken Exp $
+* $Id: call.cpp,v 1.106 2009/06/24 02:44:28 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -348,10 +348,11 @@ void	call_gui_input_string_wipe( void )
 
 /***************************************************************
 * 쥦ɥ
+* const char *name : ̾
 * const char *str : 
 ***************************************************************/
 
-void	call_gui_words_draw( const char *str )
+void	call_gui_words_draw( const char *name, const char *str )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -361,7 +362,7 @@ void	call_gui_words_draw( const char *str )
 
 	gui_begin();
 
-	gGuiWords.draw( str );
+	gGuiWords.draw( name, str );
 
 	gui_end();
 #endif
@@ -369,11 +370,15 @@ void	call_gui_words_draw( const char *str )
 
 /***************************************************************
 * 쥦ɥ (ɽ)
+* const char *name : ̾
 * const char *str : 
 * long w : ɽ
 ***************************************************************/
 
-void	call_gui_words_draw_width( const char *str, long w )
+void	call_gui_words_draw_width(
+	const char *name, const char *str,
+	long w
+)
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -383,7 +388,7 @@ void	call_gui_words_draw_width( const char *str, long w )
 
 	gui_begin();
 
-	gGuiWords.draw( str, w );
+	gGuiWords.draw( name, str, w );
 
 	gui_end();
 #endif
