@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.123 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: chr.h,v 1.125 2009/06/23 03:23:26 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -160,6 +160,9 @@ typedef unsigned long	flg_work_t;
 /* 󥹥˥ƥǤ */
 #define	FLG_WORK_STEAL_END	(1 << 1)
 
+/* 2x2 ʾΥ󥹥 1 ٤̵ͤˤե饰 */
+#define	FLG_WORK_BLAST_END	(1 << 2)
+
 /***************************************************************
 * 饹
 ***************************************************************/
@@ -534,6 +537,7 @@ typedef enum {
 
 	/* ѡƥΥ */
 	ACT_KIND_SHOP,
+	ACT_KIND_TELEPORT_PARTY,
 	ACT_KIND_RECALL,
 	ACT_KIND_MAX_N,
 } act_kind_t;
