@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.16 2009/02/14 04:43:41 bowkenken Exp $
+* $Id: gf-conf.c,v 1.20 2009/05/24 09:21:02 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -98,6 +98,11 @@ bool_t	load_game_conf( void )
 		break;
 	}
 
+	/* Сʥå */
+
+	if( chk_ver_old( &ver, 1, 0, 14 ) )
+		ver_up_game_conf_1_0_15();
+
 	/* ե򥯥 */
 
 	if( fclose( fp ) == EOF )
@@ -113,6 +118,24 @@ bool_t	load_game_conf( void )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥСѴ
+***************************************************************/
+
+void	ver_up_game_conf_1_0_15( void )
+{
+	ver_up_draw_ver_1_2_22();
+}
+
+/***************************************************************
+* եΥСѴ
+***************************************************************/
+
+void	ver_up_game_data_cnf_1_2_22( void )
+{
+	ver_up_draw_ver_1_2_22();
+}
+
 /***************************************************************
 * եΥإåΥ
 * FILE *fp : ե
@@ -380,6 +403,12 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "attribute_bold" ) == 0 ){
 		return load_game_conf_attribute_bold( id, val );
 
+	} else if( strcmp( id, "gnome" ) == 0 ){
+		return load_game_conf_gnome( id, val );
+
+	} else if( strcmp( id, "set_window_position" ) == 0 ){
+		return load_game_conf_set_window_position( id, val );
+
 	}
 
 	for( i = WIN_KIND_NULL + 1; i < WIN_KIND_MAX_N; i++ ){
@@ -709,6 +738,34 @@ bool_t	load_game_conf_joystick_number( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* ե GNOME 
+* char *id : ̻
+* long val : ɸޤϥ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_gnome( char *id, long val )
+{
+	g_flg_gnome = val;
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥɥ֤򤹤뤫?
+* char *id : ̻
+* long val : ɸޤϥ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_set_window_position( char *id, long val )
+{
+	g_flg_set_win_pos = val;
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤
 * char *id : ̻
@@ -808,6 +865,11 @@ bool_t	load_game_conf_vfx_mnstr( flg_vfx_mnstr_t flg, long val )
 
 bool_t	load_game_conf_vfx_wait( char *id, long val )
 {
+#if	1
+	set_vfx_wait( (rate_t)val );
+
+	return TRUE;
+#else
 	rate_t	ret;
 
 	ret = set_vfx_wait( (rate_t)val );
@@ -818,6 +880,7 @@ bool_t	load_game_conf_vfx_wait( char *id, long val )
 		return TRUE;
 	else
 		return FALSE;
+#endif
 }
 
 /***************************************************************
@@ -1232,6 +1295,9 @@ bool_t	load_game_data_cnf( long n )
 	if( chk_ver_old( &ver, 1, 2, 11 ) )
 		ver_up_game_data_1_2_12();
 
+	if( chk_ver_old( &ver, 1, 2, 21 ) )
+		ver_up_game_data_cnf_1_2_22();
+
 	/* եΥ */
 
 	if( fclose( fp ) == EOF )
@@ -1611,6 +1677,8 @@ bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver )
 	flg_err |= !save_game_conf_screen_size( fp, ver );
 	flg_err |= !save_game_conf_scroll( fp, ver );
 	flg_err |= !save_game_conf_flg( fp, ver );
+	flg_err |= !save_game_conf_gnome( fp, ver );
+	flg_err |= !save_game_conf_set_window_position( fp, ver );
 	flg_err |= !save_game_conf_win_pos( fp, ver );
 	flg_err |= !save_game_conf_joystick( fp, ver );
 	flg_err |= !save_game_conf_vfx( fp, ver );
@@ -1775,6 +1843,40 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥɥ֤ե饰Υ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# window manager is GNOME\n" );
+	fprintf( fp, "gnome = %ld\n",
+			(long)g_flg_gnome );
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥɥ֤ե饰Υ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# set window position\n" );
+	fprintf( fp, "set_window_position = %ld\n",
+			(long)g_flg_set_win_pos );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤Υ
 * FILE *fp : ե
