@@ -376,8 +376,8 @@ extern "C" {
 #endif
 
 bool_t	load_game_data( bool_t flg_txt, long n );
-void	set_flg_load_game_data( bool_t flg );
-bool_t	get_flg_load_game_data( void );
+void	set_flg_exit_shop( bool_t flg );
+bool_t	get_flg_exit_shop( void );
 void	appear_load_game_data( long slot_n );
 void	ver_up_game_data_1_0_4( void );
 void	ver_up_game_data_1_1_1( void );
