@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.44 2009/02/15 01:59:38 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.46 2009/06/23 05:50:26 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -1216,6 +1216,24 @@ menu_t	ls_menu_main[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/system/wizard/teleport party",
+		"<Item>",
+		'P',
+		"",
+		N_MSG_MENU_WIZARD_TELEPORT_PARTY, "",
+		cb_menu_wizard_teleport_party, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/recall",
+		"<OpenWinItem>",
+		'R',
+		"",
+		N_MSG_MENU_WIZARD_RECALL, "",
+		cb_menu_wizard_recall, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/system/wizard/on light",
 		"<Item>",
