@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.17 2007/02/28 22:33:24 bowkenken Exp $
+* $Id: mmenu.c,v 1.52 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -43,6 +43,7 @@ static pos_t	g_sub_crsr, g_pre_sub_crsr;
 static menu_t	*g_menu_dflt_main;
 
 static chr_t	*g_sub_sel_mbr;
+static abl_kind_t	g_sel_abl;
 static race_t	g_sel_race;
 static sex_t	g_sel_sex;
 static long	g_sel_class_n;
@@ -92,6 +93,10 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 
 /**/
 
+static long static_cb_menu_item__pre_sel_mbr_n;
+
+/**/
+
 void	init_var_main_menu( void )
 {
 	set_scroll_page();
@@ -107,10 +112,24 @@ void	init_main_menu( void )
 	g_menu_dflt_main = NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_main_menu( void )
+{
+	g_menu_dflt_main = NULL;
+
+	/**/
+
+	static_cb_menu_item__pre_sel_mbr_n = 0;
+}
+
 /**/
 
 char	*exec_menu_sel_mbr(
-	mbr_t **mbr, char *ttl, bool_t flg_sel_dead, bool_t flg_sel_pet
+	mbr_t **mbr, char *ttl,
+	bool_t flg_sel_dead, bool_t flg_sel_pet
 )
 {
 	party_t	*pty = get_party();
@@ -148,7 +167,7 @@ char	*exec_menu_sel_mbr(
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		str_nz_cpy( ls[k].msg, ttl,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -165,12 +184,14 @@ char	*exec_menu_sel_mbr(
 		if( *mbr == pty->mbr[i] )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/member/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/member/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pty->mbr[i]);
 		ls[k].flg = FLG_NULL;
@@ -192,12 +213,13 @@ char	*exec_menu_sel_mbr(
 		if( *mbr == pet[i] )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/member/%ld", MBR_MAX_N + i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/member/%ld", MBR_MAX_N + i );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + MBR_MAX_N + i);
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -230,6 +252,118 @@ char	*cb_menu_sel_mbr( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
+{
+	menu_t	*ls;
+	menu_t	*dflt;
+	char	key;
+	long	i, k;
+	char	*ret;
+
+	if( abl == NULL )
+		return STR_MENU_ERR;
+
+	if( chk_flg( mbr->stat, FLG_STAT_NOT_EXIST ) )
+		mbr = NULL;
+
+	dflt = NULL;
+
+	ls = ls_menu_abl;
+	k = 0;
+
+	str_nz_cpy( ls[k].path, "/ability",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/ability/--",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_SEL_ABL,
+			MENU_MSG_MAX_BYTE );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	key = 'A';
+
+	for( i = ABL_KIND_HP; i < ABL_KIND_MAX_N; i++ ){
+		if( i == *abl )
+			dflt = &(ls[k]);
+
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/ability/%ld", i );
+		str_nz_cpy( ls[k].kind, "<Item>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
+		if( mbr == NULL ){
+			str_nz_cpy( ls[k].msg, get_abl_name( (abl_kind_t)i ),
+					MENU_MSG_MAX_BYTE );
+		} else {
+			sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+					"%-3s: %ld",
+					get_abl_name( (abl_kind_t)i ),
+					mbr->abl.lev[i].n );
+		}
+		ls[k].call_back = cb_menu_sel_abl;
+		ls[k].arg = (void *)i;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+		if( (i == ABL_KIND_CHA) || (key >= (char)('A' + 12)) ){
+			key = 'A';
+
+			str_nz_cpy( ls[k].path, "/ability/--",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+	}
+
+	ls[k].path[0] = '\0';
+
+	g_sel_abl = ABL_KIND_HP;
+	ret = exec_menu( ls, dflt, NULL );
+	if( ret != NULL )
+		return ret;
+
+	*abl = g_sel_abl;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_sel_abl( menu_t **pp, menu_t **dflt )
+{
+	g_sel_abl = (abl_kind_t)(int)((*pp)->arg);
+
+	return NULL;
+}
+
+/**/
+
 char	*exec_menu_point_crsr( void )
 {
 	chk_scroll( FALSE );
@@ -282,7 +416,7 @@ char	*exec_menu_race( race_t *race )
 	}
 
 	str_nz_cpy( g_sel_race.name, get_race_str_main( &g_sel_race ),
-			RACE_NAME_MAX_LEN );
+			RACE_NAME_MAX_BYTE );
 
 	*race = g_sel_race;
 	return NULL;
@@ -357,7 +491,7 @@ char	*exec_menu_class( long *class_n )
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -370,11 +504,12 @@ char	*exec_menu_class( long *class_n )
 		if( i == *class_n )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/class/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/class/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i % LS_CLASS_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, class_tab[i].name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, class_tab[i].name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_class;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -464,8 +599,6 @@ char	*cb_menu_exec( menu_t **pp, menu_t **dflt )
 
 	exec_all_phase();
 
-	inc_turn();
-
 	return NULL;
 }
 
@@ -624,7 +757,7 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 {
 	long	mjr_chr, mjr_obj;
 	flg_map_t	flg_chr, flg_obj;
-	party_t	*pty = get_party();
+	long	sq_x, sq_y;
 	dun_t	*dun = get_dun();
 
 	mjr_chr = dun->map.chr.mjr[g_crsr.y][g_crsr.x];
@@ -635,10 +768,12 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
 	/* С */
+
 	if( mjr_chr != FACE_MJR_MBR )
 		set_flg_menu( *pp, "member", FLG_MENU_HIDDEN );
 
 	/* 󥹥 */
+
 	if( (mjr_chr == FACE_MJR_MBR) || (mjr_chr == FACE_MJR_NULL) )
 		set_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 	if( !chk_flg( flg_chr, FLG_MAP_CHR_FIND ) )
@@ -646,21 +781,30 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	if( chk_flg( flg_chr, FLG_MAP_CHR_INVISIBLE ) )
 		set_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 
+	/* 饹ܥ */
+
+	if( chk_xx_pos( g_crsr.x, g_crsr.y ) )
+		clr_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
+
 	/* ƥ */
+
 	if( get_item( g_crsr.x, g_crsr.y ) == NULL )
 		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
 
 	/* ɥ */
+
 	if( (mjr_obj != FACE_MJR_DOOR_CLOSE)
 			&& (mjr_obj != FACE_MJR_DOOR_OPEN) ){
 		set_flg_menu( *pp, "door", FLG_MENU_HIDDEN );
 	}
 
 	/*  */
+
 	if( mjr_obj != FACE_MJR_TRAP )
 		set_flg_menu( *pp, "trap", FLG_MENU_HIDDEN );
 
 	/* ʤ */
+
 	if( !chk_flg( flg_obj, FLG_MAP_OBJ_FIND ) ){
 		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "door", FLG_MENU_HIDDEN );
@@ -678,12 +822,15 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	}
 
 	/* 󥫡 */
-	if( labs( pty->square.x - g_crsr.x ) > (SQUARE_WIDTH / 2) )
+
+	get_square_pos( &sq_x, &sq_y, FALSE );
+	if( labs( sq_x - g_crsr.x ) > (SQUARE_WIDTH / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
-	if( labs( pty->square.y - g_crsr.y ) > (SQUARE_HEIGHT / 2) )
+	if( labs( sq_y - g_crsr.y ) > (SQUARE_HEIGHT / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
 
 	/* ޡ */
+
 	if( mjr_chr != FACE_MJR_MBR )
 		set_flg_menu( *pp, "clear", FLG_MENU_HIDDEN );
 
@@ -916,7 +1063,8 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 		return FALSE;
 
 	mbr->act.dflt_kind_mnstr = mbr->act.kind;
-	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg,
+			ACT_MSG_MAX_BYTE );
 
 	mark_mnstr( mbr, mnstr, g_sel_dist );
 
@@ -1061,7 +1209,7 @@ bool_t	menu_mark_pos( pos_t pos1, pos_t pos2 )
 	if( !set_chr_act( mbr, ACT_KIND_NULL, NULL, NULL, 0, 0 ) )
 		return FALSE;
 
-	str_nz_cpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_BYTE );
 	mark_pos( mbr, pos2.x, pos2.y, DIST_NEAR );
 
 	draw_mbr_stat( mbr );
@@ -1083,9 +1231,6 @@ bool_t	menu_mark_square_pos( pos_t pos )
 	sq->pre_x = sq->x;
 	sq->pre_y = sq->y;
 
-	sq->dir_x = 0;
-	sq->dir_y = 0;
-
 	flg_loop = TRUE;
 	while( flg_loop ){
 		switch( get_key( g_flg_clr_key_buf ) ){
@@ -1096,22 +1241,22 @@ bool_t	menu_mark_square_pos( pos_t pos )
 		case CASE_ENTER:
 		case CASE_CRSR_UP:
 		case '-':
-			sq->dir_y = -1;
+			sq->dir = SQUARE_DIR_NORTH;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_DOWN:
 		case '+':
-			sq->dir_y = +1;
+			sq->dir = SQUARE_DIR_SOUTH;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_LEFT:
 		case '/':
-			sq->dir_x = -1;
+			sq->dir = SQUARE_DIR_WEST;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_RIGHT:
 		case '*':
-			sq->dir_x = +1;
+			sq->dir = SQUARE_DIR_EAST;
 			flg_loop = FALSE;
 			break;
 		}
@@ -1120,8 +1265,7 @@ bool_t	menu_mark_square_pos( pos_t pos )
 	sq->x = pos.x;
 	sq->y = pos.y;
 	set_square_mbr( sq );
-
-	set_mbr_dir();
+	reset_mbr_dir();
 
 	clr_msg();
 	draw_square();
@@ -1282,16 +1426,20 @@ char	*cb_menu_dist_act( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 {
-	static long pre_sel_mbr_n = 0;
+	long pre_sel_mbr_n;
 	party_t	*pty = get_party();
 	menu_t	*ls;
 	mbr_t	*mbr;
 	long	i, j, k;
 
+	pre_sel_mbr_n = static_cb_menu_item__pre_sel_mbr_n;
+
 	if( g_sel_mbr_n <= -1 )
 		g_sel_mbr_n = pre_sel_mbr_n;
 	else
 		pre_sel_mbr_n = g_sel_mbr_n;
+	static_cb_menu_item__pre_sel_mbr_n = pre_sel_mbr_n;
+
 	if( g_sel_mbr_n <= -1 )
 		return STR_MENU_ERR;
 	if( g_sel_mbr_n >= MBR_MAX_N )
@@ -1336,40 +1484,46 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
 		item = get_mbr_item_asgn( pty->mbr[i] );
-		p = item->next;
-		for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
-			if( p == item )
-				break;
+		if( item != NULL ){
+			p = item->next;
+			for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
+				if( p == item )
+					break;
 
-			sprintf( ls[k].path, "/item/%ld%c",
-					i, (char)('A' + j) );
-			str_nz_cpy( ls[k].kind, "<Branch>",
-					MENU_KIND_MAX_LEN );
-			ls[k].accel_key = (char)('A' + j);
-			ls[k].short_key[0] = '\0';
-			ls[k].n_msg = N_MSG_NULL;
-			sprintf( ls[k].msg, " %s", p->name );
-			ls[k].call_back = cb_menu_item_sel;
-			ls[k].arg = NULL;
-			ls[k].flg = FLG_NULL;
-			k++;
+				sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+						"/item/%ld%c",
+						i, (char)('A' + j) );
+				str_nz_cpy( ls[k].kind, "<Branch>",
+						MENU_KIND_MAX_LEN );
+				ls[k].accel_key = (char)('A' + j);
+				ls[k].short_key[0] = '\0';
+				ls[k].n_msg = N_MSG_NULL;
+				sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+						" %s", p->name );
+				ls[k].call_back = cb_menu_item_sel;
+				ls[k].arg = NULL;
+				ls[k].flg = FLG_NULL;
+				k++;
+			}
 		}
 
-		sprintf( ls[k].path, "/item/%ld%s", i, "equip" );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/item/%ld%s", i, "equip" );
 		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg, MSG_MENU_ITEM_LS_EQUIP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_goto_equip;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -1450,7 +1604,11 @@ char	*cb_menu_item_sel( menu_t **pp, menu_t **dflt )
 	g_sel_item = NULL;
 
 	item_idx = node[1] - 'A';
+
 	item_head = get_mbr_item_asgn( pty->mbr[g_sel_mbr_n] );
+	if( item_head == NULL )
+		return STR_MENU_ERR;
+
 	item = item_head->next;
 	for( i = 0; i < MBR_ITEM_MAX_N; i++ ){
 		if( item == item_head )
@@ -1496,6 +1654,7 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 	clr_flg_menu( *pp, "send", FLG_MENU_HIDDEN );
 	clr_flg_menu( *pp, "receive", FLG_MENU_HIDDEN );
 	clr_flg_menu( *pp, "drop", FLG_MENU_HIDDEN );
+	clr_flg_menu( *pp, "alias", FLG_MENU_HIDDEN );
 	clr_flg_menu( *pp, "check", FLG_MENU_HIDDEN );
 
 	switch( g_sel_item->kind ){
@@ -1518,7 +1677,10 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 	case ITEM_KIND_ACCE:
 	case ITEM_KIND_INST:
 	case ITEM_KIND_ANTHOLOGY:
+		break;
 	case ITEM_KIND_LIGHT:
+		clr_flg_menu( *pp, "rub", FLG_MENU_HIDDEN );
+		break;
 	case ITEM_KIND_SPIKE:
 		break;
 	case ITEM_KIND_FOOD:
@@ -1677,7 +1839,7 @@ char	*cb_menu_item_smoke( menu_t **pp, menu_t **dflt )
 		mbr->act.n = EQUIP_KIND_HEAD;
 
 		str_nz_cpy( mbr->act.msg, MSG_ACT_TOBACCO_SMOKE,
-				ACT_MSG_MAX_LEN );
+				ACT_MSG_MAX_BYTE );
 	}
 
 	return ret;
@@ -1701,18 +1863,20 @@ char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	lamp = &(lamp[EQUIP_KIND_LIGHT_SOURCE]);
 
-	tab = get_light_tab( lamp->dat.light.kind );
+	tab = get_light_tab( lamp->dat.light.kind,
+			lamp->dat.light.wish_level );
 
 	if( (lamp->kind != ITEM_KIND_LIGHT) || !tab->flg_fill ){
 		print_msg( FLG_NULL, MSG_ERR_FILL_LAMP );
 		return STR_MENU_ERR;
 	}
 
-	if( set_chr_act( mbr, (act_kind_t)(long)((*pp)->arg),
+	if( !set_chr_act( mbr, (act_kind_t)(long)((*pp)->arg),
 			g_sel_item, NULL, 0, 0 ) ){
-		return NULL;
+		return STR_MENU_ERR;
 	}
-	return STR_MENU_ERR;
+
+	return NULL;
 }
 
 /**/
@@ -1769,10 +1933,14 @@ char	*cb_menu_item_send( menu_t **pp, menu_t **dflt )
 			g_sel_item, mbr2, n, 0 ) ){
 		return STR_MENU_CANCEL;
 	}
-
 	mark_mbr( mbr, mbr2, DIST_NEAR );
 
-	return NULL;
+	if( !g_flg_send_item_exec_turn ){
+		send_item( mbr );
+		clr_chr_trgt_act( mbr, TRUE );
+	}
+
+	return "/item";
 }
 
 /**/
@@ -1809,10 +1977,14 @@ char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt )
 			g_sel_item, mbr, n, 0 ) ){
 		return STR_MENU_CANCEL;
 	}
-
 	mark_mbr( mbr2, mbr, DIST_NEAR );
 
-	return NULL;
+	if( !g_flg_send_item_exec_turn ){
+		receive_item( mbr2 );
+		clr_chr_trgt_act( mbr2, TRUE );
+	}
+
+	return "/item";
 }
 
 /**/
@@ -1846,6 +2018,18 @@ char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_item_alias( menu_t **pp, menu_t **dflt )
+{
+	if( g_sel_item == NULL )
+		return STR_MENU_ERR;
+
+	set_item_alias( g_sel_item );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 char	*cb_menu_item_chk( menu_t **pp, menu_t **dflt )
 {
 	if( g_sel_item == NULL )
@@ -1947,7 +2131,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg,
-				pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+				pty->mbr[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -1958,11 +2142,15 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			equip_kind_t	eq_k;
 			char	*msg;
 
+			if( equip == NULL )
+				break;
+
 			eq_k = ls_equip_msg[j].kind;
 
 			msg = MSG( ls_equip_msg[j].n_msg );
 
-			sprintf( ls[k].path, "/equip/%ld%c",
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+					"/equip/%ld%c",
 					i, (char)('A' + j) );
 			str_nz_cpy( ls[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
@@ -1970,12 +2158,14 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			if( equip[eq_k].kind == ITEM_KIND_NULL ){
-				sprintf( ls[k].msg,
+				sn_printf( ls[k].msg,
+						MENU_MSG_MAX_BYTE,
 						MSG_FMT_EQUIP_NULL,
 						equip_ttl_max_len,
 						msg );
 			} else {
-				sprintf( ls[k].msg,
+				sn_printf( ls[k].msg,
+						MENU_MSG_MAX_BYTE,
 						MSG_FMT_EQUIP,
 						equip_ttl_max_len,
 						msg,
@@ -1987,7 +2177,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			k++;
 		}
 
-		sprintf( ls[k].path,
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
 				"/equip/%ld%s", i, "item" );
 		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
@@ -1996,7 +2186,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg,
 				MSG_MENU_EQUIP_LS_ITEM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_goto_item;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -2115,17 +2305,20 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 	k++;
 
 	item = get_mbr_item_asgn( pty->mbr[g_sel_mbr_n] );
+	if( item == NULL )
+		return STR_MENU_ERR;
 	p = item->next;
 	for( i = 0; i < MBR_ITEM_MAX_N; i++, p = p->next ){
 		if( p == item )
 			break;
 
-		sprintf( ls[k].path, "/wear/%c", (char)('A' + i) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/wear/%c", (char)('A' + i) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_equip_wear;
 		ls[k].arg = p;
 		ls[k].flg = FLG_NULL;
@@ -2294,44 +2487,73 @@ char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 {
-	square_t	*sq;
-
 	set_menu_dflt_main( *pp );
 
+	menu_move_square();
+
+	return NULL;
+}
+
+/**/
+
+void	menu_move_square( void )
+{
+	square_t	*sq;
+
 	sq = get_square_mbr();
 
 	sq->pre_x = sq->x;
 	sq->pre_y = sq->y;
 
-	sq->dir_x = 0;
-	sq->dir_y = 0;
+	sq->pre_dir = sq->dir;
+	sq->dir = SQUARE_DIR_MAX_N;
+
+	/* ưθ˹碌ƤΥ󥫡θꤹ */
+
 	if( labs( sq->x - g_crsr.x ) > labs( sq->y - g_crsr.y ) ){
 		if( g_crsr.x < sq->x ){
-			sq->dir_x = -1;
+			sq->dir = SQUARE_DIR_WEST;
 		} else if( g_crsr.x > sq->x ){
-			sq->dir_x = +1;
+			sq->dir = SQUARE_DIR_EAST;
 		}
 	} else {
 		if( g_crsr.y < sq->y ){
-			sq->dir_y = -1;
+			sq->dir = SQUARE_DIR_NORTH;
 		} else if( g_crsr.y > sq->y ){
-			sq->dir_y = +1;
+			sq->dir = SQUARE_DIR_SOUTH;
 		}
 	}
-	if( (sq->dir_x == 0) && (sq->dir_y == 0) ){
-		sq->dir_x = 0;
-		sq->dir_y = -1;
+
+	/* Ʊɸǥ󥫡ꤷ 90 ٤ŤĲž */
+
+	if( sq->dir == SQUARE_DIR_MAX_N ){
+		switch( sq->pre_dir ){
+		case SQUARE_DIR_NORTH:
+			sq->dir = SQUARE_DIR_EAST;
+			break;
+		case SQUARE_DIR_EAST:
+			sq->dir = SQUARE_DIR_SOUTH;
+			break;
+		case SQUARE_DIR_SOUTH:
+			sq->dir = SQUARE_DIR_WEST;
+			break;
+		case SQUARE_DIR_WEST:
+			sq->dir = SQUARE_DIR_NORTH;
+			break;
+		case SQUARE_DIR_MAX_N:
+			sq->dir = SQUARE_DIR_NORTH;
+			break;
+		}
+		if( sq->dir == SQUARE_DIR_MAX_N )
+			sq->dir = SQUARE_DIR_NORTH;
 	}
 
 	sq->x = g_crsr.x;
 	sq->y = g_crsr.y;
-
 	set_square_mbr( sq );
+	reset_mbr_dir();
 
-	set_mbr_dir();
 	draw_square();
-
-	return NULL;
 }
 
 /**/
@@ -2380,31 +2602,47 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_load( menu_t **pp, menu_t **dflt )
+char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt )
 {
-	menu_load( TRUE );
+	menu_load_wiz();
 
 	return STR_MENU_CANCEL;
 }
 
 /**/
 
-char	*cb_menu_save( menu_t **pp, menu_t **dflt )
+char	*cb_menu_save_wiz( menu_t **pp, menu_t **dflt )
 {
-	menu_save( TRUE );
+	menu_save_wiz();
 
 	return STR_MENU_CANCEL;
 }
 
 /**/
 
-bool_t	menu_load( bool_t flg_txt )
+void	menu_load_wiz( void )
+{
+	if( menu_load( TRUE, FALSE ) )
+		reset_all_save( TRUE );
+}
+
+/**/
+
+void	menu_save_wiz( void )
+{
+	if( menu_save( TRUE ) )
+		reset_all_save( TRUE );
+}
+
+/**/
+
+bool_t	menu_load( bool_t flg_txt, bool_t flg_new_game )
 {
 	long	n;
 	ask_t	ask;
 
-	n = menu_sel_save_load( FALSE, flg_txt );
-	if( n <= -1 )
+	n = menu_sel_save_load( FALSE, flg_txt, flg_new_game );
+	if( n == SAVE_N_SEL )
 		return FALSE;
 
 	ask = exec_menu_ask( MSG_TTL_MENU_ASK_LOAD, ASK_NO, TRUE );
@@ -2413,13 +2651,15 @@ bool_t	menu_load( bool_t flg_txt )
 
 	load_game_conf();
 	load_game_data( flg_txt, n );
+	if( n != SAVE_N_AUTO )
+		bgn_reg_replay( SAVE_N_BUG_REPO );
 
 	if( flg_txt )
 		set_flg_no_save( TRUE );
 	else
 		set_flg_no_save( FALSE );
 
-	print_msg( FLG_NULL, MSG_MENU_LOAD_SUCCESS );
+	print_msg( FLG_NULL, MSG_MENU_LOAD_SUCCESS, n );
 
 	return TRUE;
 }
@@ -2428,7 +2668,13 @@ bool_t	menu_load( bool_t flg_txt )
 
 bool_t	menu_save( bool_t flg_txt )
 {
-	long	n;
+	return menu_save_n( flg_txt, SAVE_N_SEL );
+}
+
+/**/
+
+bool_t	menu_save_n( bool_t flg_txt, long save_n )
+{
 	ask_t	ask;
 
 	if( !flg_txt && g_flg_no_save ){
@@ -2436,27 +2682,45 @@ bool_t	menu_save( bool_t flg_txt )
 		return FALSE;
 	}
 
-	n = menu_sel_save_load( TRUE, flg_txt );
-	if( n <= -1 )
-		return FALSE;
+	if( save_n == SAVE_N_SEL ){
+		save_n = menu_sel_save_load( TRUE, flg_txt, FALSE );
 
-	ask = exec_menu_ask( MSG_TTL_MENU_ASK_SAVE, ASK_NO, TRUE );
-	if( ask != ASK_YES )
-		return FALSE;
+		if( save_n == SAVE_N_AUTO ){
+			print_msg( FLG_MSG_ERR,
+					MSG_ERR_MENU_SAVE_N_SEL_AUTO );
+			return FALSE;
+		}
+
+		if( save_n == SAVE_N_SEL )
+			return FALSE;
+	}
+
+	if( save_n != SAVE_N_AUTO ){
+		ask = exec_menu_ask( MSG_TTL_MENU_ASK_SAVE, ASK_NO, TRUE );
+		if( ask != ASK_YES )
+			return FALSE;
+	}
 
 	save_dun();
 	save_town();
 	save_game_conf();
-	save_game_data( flg_txt, n );
+	save_game_data( flg_txt, save_n );
+	if( save_n != SAVE_N_AUTO )
+		bgn_reg_replay( SAVE_N_BUG_REPO );
 
-	print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS );
+	if( flg_txt )
+		print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS_TXT, save_n );
+	else
+		print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS_BIN, save_n );
 
 	return TRUE;
 }
 
 /**/
 
-long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
+long	menu_sel_save_load(
+	bool_t flg_save, bool_t flg_txt, bool_t flg_new_game
+)
 {
 	menu_t	*ls;
 	menu_t	*dflt;
@@ -2483,8 +2747,11 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 
 	for( i = 0; i < MENU_SAVE_LOAD_MAX_N; i++ ){
 		bool_t	flg_exist_data;
+		bool_t	flg_page;
 
-		if( (i != 0) && (i % MENU_SAVE_LOAD_N_PER_PAGE == 0) ){
+		flg_page = ((i % MENU_SAVE_LOAD_N_PER_PAGE) == 0);
+
+		if( flg_page && (i != 0) ){
 			key = 'A';
 
 			str_nz_cpy( ls[k].path,
@@ -2502,18 +2769,36 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 			k++;
 		}
 
-		if( i % MENU_SAVE_LOAD_N_PER_PAGE == 0 ){
+		if( flg_page ){
 			set_ttl_menu_save_load( &(ls[k]),
 					flg_save, flg_txt );
 			k++;
 		}
 
-		sprintf( ls[k].path, "/save load list/%ld", i );
+		if( flg_new_game && (i == 0) ){
+			str_nz_cpy( ls[k].path,
+					"/save load list/new game",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = 'Z';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_SAVE_LOAD_TTL_NEW_GAME;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = cb_menu_new_game;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/save load list/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		flg_exist_data = get_save_load_ttl( ls[k].msg, i, flg_txt );
+		flg_exist_data = get_save_load_ttl( ls[k].msg, i,
+				flg_txt, FALSE );
 		ls[k].call_back = cb_menu_save_load;
 		if( flg_save || flg_exist_data )
 			ls[k].arg = (void *)i;
@@ -2526,22 +2811,26 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 	}
 	ls[k].path[0] = '\0';
 
-	g_sel_save_load_n = -1;
+	g_sel_save_load_n = SAVE_N_SEL;
 
 	while( 1 ){
 		ret = exec_menu( ls, dflt, NULL );
 
 		if( ret == NULL ){
-			if( !flg_save && (g_sel_save_load_n <= -1) )
-				continue;
-			else
+			if( g_sel_save_load_n == SAVE_N_SEL ){
+				if( flg_new_game )
+					return SAVE_N_SEL;
+				if( !flg_save )
+					continue;
+			} else {
 				return g_sel_save_load_n;
+			}
 		}
 
-		return -1;
+		return SAVE_N_SEL;
 	}
 
-	return -1;
+	return SAVE_N_SEL;
 }
 
 /**/
@@ -2558,18 +2847,18 @@ void	set_ttl_menu_save_load(
 	if( flg_txt ){
 		if( flg_save ){
 			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_SAVE,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		} else {
 			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_LOAD,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		}
 	} else {
 		if( flg_save ){
 			str_nz_cpy( ls->msg, MSG_MENU_BAR_SAVE,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		} else {
 			str_nz_cpy( ls->msg, MSG_MENU_BAR_LOAD,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		}
 	}
 	ls->call_back = NULL;
@@ -2592,6 +2881,13 @@ char	*cb_menu_save_load( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_new_game( menu_t **pp, menu_t **dflt )
+{
+	return NULL;
+}
+
+/**/
+
 void	set_flg_no_save( bool_t flg )
 {
 	g_flg_no_save = flg;
@@ -2599,6 +2895,13 @@ void	set_flg_no_save( bool_t flg )
 
 /**/
 
+bool_t	get_flg_no_save( void )
+{
+	return g_flg_no_save;
+}
+
+/**/
+
 bool_t	exec_menu_identify_item( mbr_t *mbr )
 {
 	party_t	*pty = get_party();
@@ -2609,7 +2912,7 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( chk_flg_or( mbr->stat,
@@ -2652,22 +2955,43 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
 		item = get_mbr_item_asgn( pty->mbr[i] );
-		p = item->next;
-		for( j = 0; j < MBR_ITEM_MAX_N; j++, k++, p = p->next ){
+		if( item == NULL )
+			p = NULL;
+		else
+			p = item->next;
+		j = 0;
+		if( (p == NULL) || (p == item) ){
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+					"/identify item/unknown %c",
+					(char)('A' + i) );
+			str_nz_cpy( ls[k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = (char)('A' + j);
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_ITEM_UNKNOWN;
+			str_nz_cpy( ls[k].msg, MSG_ITEM_UNKNOWN,
+					MENU_MSG_MAX_BYTE );
+			ls[k].call_back = cb_menu_identify_item_unknown;
+			ls[k].arg = (void *)NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+		for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
 			if( p == item )
 				break;
 
 			if( (pty->mbr[i] == mbr) && (dflt == NULL) )
 				dflt = &(ls[k]);
 
-			sprintf( ls[k].path,
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
 					"/identify item/%c",
 					(char)('A' + j) );
 			str_nz_cpy( ls[k].kind, "<Item>",
@@ -2675,10 +2999,12 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+			str_nz_cpy( ls[k].msg, p->name,
+					MENU_MSG_MAX_BYTE );
 			ls[k].call_back = cb_menu_identify_item;
 			ls[k].arg = (void *)p;
 			ls[k].flg = FLG_NULL;
+			k++;
 		}
 
 		str_nz_cpy( ls[k].path, "/identify item/--",
@@ -2720,6 +3046,13 @@ char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_identify_item_unknown( menu_t **pp, menu_t **dflt )
+{
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 bool_t	exec_menu_resurrection( mbr_t *mbr )
 {
 	party_t	*pty = get_party();
@@ -2731,7 +3064,7 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
-	if( mbr->kind != CHR_KIND_MBR )
+	if( !is_mbr( mbr ) )
 		return FALSE;
 
 	if( chk_flg_or( mbr->stat,
@@ -2769,7 +3102,7 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_RESURRECTION,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2781,14 +3114,16 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		if( !chk_flg( pty->mbr[i]->stat, FLG_STAT_DEAD ) )
 			continue;
 
-		sprintf( ls[k].path, "/resurrection/%c",
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/resurrection/%c",
 				(char)('A' + i) );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pty->mbr[i];
 		ls[k].flg = FLG_NULL;
@@ -2804,14 +3139,15 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		if( !chk_flg( pet[i]->stat, FLG_STAT_DEAD ) )
 			continue;
 
-		sprintf( ls[k].path, "/resurrection/%c",
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/resurrection/%c",
 				(char)('A' + i + MBR_MAX_N) );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i + MBR_MAX_N);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pet[i];
 		ls[k].flg = FLG_NULL;
