@@ -44,7 +44,7 @@ void	chk_trap_party( void );
 bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
 bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
 bool_t	chk_auto_door_mbr_sub( mbr_t *mbr, long x, long y );
-void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over );
+void	die_mbr( mbr_t *mbr, bool_t flg_msg, bool_t flg_chk_game_over );
 bool_t	chk_can_act_mbr( mbr_t *p );
 bool_t	set_mbr_act_auto_mnstr( mbr_t *mbr, long x, long y );
 void	mbr_peep_door( mbr_t *mbr, long dr_n );
